function [save_status,Final_IT_array,Final_dt_array,Final_mean_I_array,Final_level_pts,event_area,end_to_end_trans_time,trans_time_FWHM,FWHM_bounds,levels,level_type,I0_new]=My_CUSTOM_FUNCTION(pad_data,sampling_frequency)

%pad_data:  padded event raw data
%time_length_PD:  Time in points (e.g., 1,2,3,4....rather than actual time)
%sampling_frequency:  sampling frequency in Hz

% FOLLOWING OUTPUTS ARE NEEDED FROM YOUR CUSTOM FUNCTION
% 1.	save_status:  Whether you want to save the event (1)or not (0)
% 2.	Final_IT_array:  Nx2 matrix containing the fit values. Column 1 (time)and Column 2 (current)
% 3.	Final_dt_array:  Translocation Time of each fit level in points. Save as a column vector
% 4.	Final_mean_I_array:Current depth (i.e., delta I) of each level in pico amps. Save as a column vector
% 5.	Final_level_pts: Boundary points of each level. See Help Document for more details
% 6.	event_area:  Area of the event in fC
% 7.	end_to_end_trans_time:  Two side of the blockade through the fit
% 8.	trans_time_FWHM: Full Width Half Max Translocation time in micro seconds.
% 9.	FWHM_bounds:  Bounds of the FWHM time () for viewing
% 10.	levels:  Number of event levels
% 11.	level_type:  Type of each level: downward (1), upward (2) or flat (3)
% 12.	I0_new:  Baseline Current Value


%AN EXAMPLE CODE IS PROVIDED BELOW

ipt=findchangepts(pad_data,'MaxNumChanges',2);%finds the two most significant change points. This would separate baselines on left and right from the actual event
if length(ipt)==2 % to make sure there are acutally two change points
    
    BSL=pad_data(1:ipt(1));%left baseline
    BSR=pad_data(ipt(2):end);%right baseline
    event_data=pad_data(ipt(1):ipt(2));%event data
    
    mean_BSL=mean(BSL);%mean of left baseline
    mean_BSR=mean(BSR);%mean of right baseline
    mean_event_data=mean(event_data);% mean of event data
    
    %Left baseline Fit construction
    left_I=repmat(mean_BSL,ipt(1)-1,1);
    left_t=(1:(ipt(1)-1))';
    left_It=[left_t left_I];
    
    %Right baseline Fit construction
    BSR_length=(length(pad_data)-(ipt(2)+1))+1;%think your Right Baseline spans from 60-100. The mere substraction gives you 40 yet the it covers 41 points. Hence the +1
    right_I=repmat(mean_BSR,BSR_length,1);
    right_t=((ipt(2)+1):length(pad_data))';
    right_It=[right_t right_I];
    
    %Event Fit construction
    event_length=(ipt(2)-ipt(1))+1;%think your event spans from 53-60. The mere substraction gives you 7 yet the it covers 8 points. Hence the +1
    event_I=repmat(mean_event_data,event_length,1);
    event_t=(ipt(1):ipt(2))';
    event_It=[event_t event_I];
    
    %Finalizing the outputs
    save_status=1;
    Final_IT_array=[left_It;event_It;right_It];
    Final_dt_array=event_length;
    Final_mean_I_array=mean_event_data;
    Final_level_pts=ipt;
    end_to_end_trans_time=(sum(Final_dt_array)/sampling_frequency)*10^6;
    %levels=length(Final_level_pts)-1;
    levels=1;
    level_type=1;
    I0_new=mean([mean_BSL;mean_BSR]);
    
    %Simple Event Area Calculation
    Event_time_sec=event_t/sampling_frequency;
    event_area=(trapz(Event_time_sec,event_I))*1000;%in fC
    
    %Simple FWHM calculation
    half_delta_I=I0_new-((I0_new-min(Final_mean_I_array))/2);
    half_max_data=event_data(event_data<=half_delta_I);
    half_max_length=length(half_max_data);
    trans_time_FWHM=(half_max_length/sampling_frequency)*10^6;
    %Saving of event bounds of FWHM for viewving
    start_time=(ipt(1)+find(event_data<=half_delta_I, 1, 'first'))-1;
    end_time=start_time+half_max_length;
    FWHM_bounds=[start_time half_max_data(1);end_time half_max_data(end)];
    
else
save_status=0;
Final_IT_array=zeros(1,2);
Final_dt_array=0;
Final_mean_I_array=0;
Final_level_pts=0;
event_area=0;
end_to_end_trans_time=0;
trans_time_FWHM=0;
FWHM_bounds=zeros(2,2);
levels=0;
level_type=3;
I0_new=0;

end

end